@@ -1,4 +1,4 @@
-import importlib
+import importlib, collections
 
 from enum import Enum
 from cro_validate.enum import DataType
@@ -246,22 +246,38 @@ class Definition:
 			)
 		return validator
 
-	def _validate_array(self, results, field_fqn, field_name, definition, values, dependent_values):
-		if isinstance(values, list):
+	def _validate_array(
+				self,
+				results,
+				field_fqn,
+				field_name,
+				definition,
+				value,
+				dependent_values,
+				**rules_kw):
+		if isinstance(value, list):
 			pass
-		elif isinstance(values, set):
-			values = [v for v in values]
+		elif isinstance(value, set):
+			value = [v for v in value]
 		else:
-			raise Config.exception_factory.create_input_error(field_fqn, 'Expected array, received: {0}'.format(type(values)))
+			raise Config.exception_factory.create_input_error(field_fqn, 'Expected array, received: {0}'.format(type(value)))
 		items = []
 		i = 0
-		for entry in values:
+		for entry in value:
 			item = Index.validate_input(None, field_fqn + '[' + str(i) + ']', field_name, self.data_format, entry, dependent_values)
 			items.append(item[field_name])
 			i = i + 1
 		results[field_name] = items
 
-	def _assign_value(self, results, field_fqn, field_name, definition, value, dependent_values):
+	def _assign_value(
+				self,
+				results,
+				field_fqn,
+				field_name,
+				definition,
+				value,
+				dependent_values,
+				**rules_kw):
 		results[field_name] = value
 
 	def validate(
@@ -319,7 +335,8 @@ class Definition:
 						field_name,
 						dependent_definition_name,
 						results[field_name],
-						dependent_values
+						dependent_values,
+						**rules_kw
 					)
 			else:
 				self.validator(
@@ -328,7 +345,8 @@ class Definition:
 						field_name,
 						self,
 						results[field_name],
-						dependent_values
+						dependent_values,
+						**rules_kw
 					)
 			for rule in self.rules:
 				results[field_name] = rule.execute(field_fqn, results[field_name], **rules_kw)
@@ -660,7 +678,8 @@ class Index:
 				definition,
 				**rules_kw
 			):
-		if definition.get_data_type() not in Index._data_type_rules:
+		data_type = definition.get_data_type()
+		if data_type not in Index._data_type_rules:
 			return
 		if definition.get_name() in Index._data_type_rule_exceptions:
 			return
@@ -674,7 +693,11 @@ class Index:
 				definition,
 				**rules_kw
 			):
-		if definition.get_data_format() not in Index._data_format_rules:
+		data_format = definition.get_data_format()
+		if not isinstance(data_format, collections.Hashable):
+			# currently not supported; FUTURES
+			return
+		if data_format not in Index._data_format_rules:
 			return
 		if definition.get_name() in Index._data_format_rule_exceptions:
 			return
