@@ -5,7 +5,8 @@ class Index(dict):
 	def __getattr__(self, name):
 		resolved = Config.parameter_name_resolver.resolve(self, name)
 		if resolved is None:
-			raise Config.exception_factory.create_input_error(name, 'Unresolved name.')
+			#raise Config.exception_factory.create_input_error(name, 'Unresolved name.')
+			raise Config.exception_factory.create_internal_error(name, 'Unresolved name.')
 		result = self[resolved]
 		return result
 
