@@ -137,17 +137,18 @@ class Field:
 
 
 class Validator:
-	def _validate(self, validated, fqn, field_name, definition, value, dependent_values):
+	def _validate(self, validated, fqn, field_name, definition, value, dependent_values, **rules_kw):
 		results = Parameters.Index.ensure(validated)
-		model_result = self.model_validator(None, fqn, field_name, definition, value)
+		cb = Definitions.Index.validate_input
+		model_result = self.model_validator(None, fqn, field_name, definition, value, cb, **rules_kw)
 		results[field_name] = model_result
 
 	def __init__(self, name, model_validator):
 		self.name = name
 		self.model_validator = model_validator
 
-	def __call__(self, results, fqn, field_name, definition, value, dependent_values):
-		return self._validate(results, fqn, field_name, definition, value, dependent_values)
+	def __call__(self, results, fqn, field_name, definition, value, dependent_values, **rules_kw):
+		return self._validate(results, fqn, field_name, definition, value, dependent_values, **rules_kw)
 
 	def is_field_required(self, field_name):
 		if field_name in self.model_validator.required:
@@ -308,7 +309,7 @@ class ModelValidator:
 			delattr(target, src_field_name)
 			setattr(target, target_field_name, tmp)
 
-	def _validate(self, validated, fqn, values, callback):
+	def _iterate(self, validated, fqn, values, callback, **rules_kw):
 		# Some objects could have dangling __dict__ entries (e.g. WebCore context)
 		# and other objects shouldn't be smashed, so the original ref must be
 		# returned.
@@ -369,7 +370,8 @@ class ModelValidator:
 					field_name=entry,
 					definition_or_name=field_definition_name,
 					value=kw[entry],
-					dependent_values=dependent_values)
+					dependent_values=dependent_values,
+					**rules_kw)
 			for definition_result_entry in definition_result:
 				self._set_output_value(
 						definition_result_entry,
@@ -508,10 +510,11 @@ class ModelValidator:
 		self.add_dependencies(dependencies)
 		self.add_default_values(default_values)
 
-	def __call__(self, validated, fqn, field_name, definition, values):
-		return self._validate(
+	def __call__(self, validated, fqn, field_name, definition, values, cb, **rules_kw):
+		return self._iterate(
 				validated,
 				fqn,
 				values,
-				Definitions.Index.validate_input
+				cb,
+				**rules_kw
 			)
\ No newline at end of file
